import 'base.dart';

class PropertyBuilder {
  const PropertyBuilder({
    required this.name,
    required this.type,
    required this.isPrivate,
    this.defaultValue,
    this.fromJsonParser = false,
  });
  final String name;
  final String type;
  final bool isPrivate;
  final String? defaultValue;
  final bool fromJsonParser;
  String get fieldName => '${isPrivate ? '_' : ''}$argumentName';
  String get argumentName => '${createFieldName(name)}';

  String buildConstructorParameter({bool nullSafety = true}) {
    final result = StringBuffer();
    result.write(' ${nullSafety ? '' : '@'}required');
    result.write(' ${isPrivate ? '$type ' : 'this.'}$argumentName');
    return result.toString();
  }

  List<String> buildConstructorInitializers({bool nullSafety = true}) {
    return [
      if (!nullSafety) 'assert($argumentName != null)',
      if (isPrivate) '$fieldName = $argumentName',
    ];
  }

  String buildField({bool nullSafety = true}) {
    return 'final $type $fieldName;';
  }
}
